## -----------------------------------------------------------------------------
#| eval: false
## install.packages("rJavaEnv")


## -----------------------------------------------------------------------------
#| eval: false
## install.packages('rJavaEnv',
##   repos = c('https://e-kotov.r-universe.dev', 'https://cloud.r-project.org')
## )


## -----------------------------------------------------------------------------
project_dir <- tempdir()
setwd(project_dir)


## -----------------------------------------------------------------------------
library(rJavaEnv)
java_quick_install(version = 21)


## -----------------------------------------------------------------------------
java_check_version_rjava()


## -----------------------------------------------------------------------------
java_check_version_cmd()


## -----------------------------------------------------------------------------
java_env_unset()


## -----------------------------------------------------------------------------
java_clear("project", delete_all = TRUE)


## -----------------------------------------------------------------------------
java_clear("project", delete_all = TRUE)
java_clear("installed", delete_all = TRUE)
java_clear("distrib", delete_all = TRUE)


## -----------------------------------------------------------------------------
java_env_unset()

